@@ -26,13 +26,26 @@ FROM
             pg_class cl
         LEFT OUTER JOIN pg_shdescription descr ON (
             cl.oid=descr.objoid AND descr.classoid='pg_class'::regclass)
-        WHERE cl.oid = {{ vid }}::OID AND relkind = 'v'
+        WHERE
+            cl.oid = {{ vid }}::OID AND relkind = 'v'
         ) acl,
-        aclexplode(relacl) d
+        (SELECT
+            (d).grantee AS grantee,
+            (d).grantor AS grantor,
+            (d).is_grantable AS is_grantable,
+            (d).privilege_type AS privilege_type
+        FROM
+            (SELECT
+                aclexplode(relacl) AS d
+             FROM
+                pg_class cl1
+             WHERE
+                cl1.oid = {{ vid }}
+            ) a
+        ) d
     ) d
-LEFT JOIN pg_catalog.pg_roles g ON (d.grantor = g.oid)
-LEFT JOIN pg_catalog.pg_roles gt ON (d.grantee = gt.oid)
+    LEFT JOIN pg_catalog.pg_roles g ON (d.grantor = g.oid)
+    LEFT JOIN pg_catalog.pg_roles gt ON (d.grantee = gt.oid)
 GROUP BY
-    g.rolname,
-    gt.rolname
+    g.rolname, gt.rolname
 {% endif %}
